let argRegex = new RegExp('(\-\-[a-zA-Z0-9]+)(=)(.*)');

/**
 * Parses args from node process
 * @returns { {[ key: string ]: string | string[]} } parsed args array;
 * if the arg followed format `--arg=val`, it will be indexed as `args[arg]=val`;
 * otherwise it will be pushed to an array under `args['_']`
 */
const parseArgs = () => {
  let _args = { '_': [] };
  [...process.argv.slice(2)].forEach(arg => {
    let result = argRegex.exec(arg);
    if (!!result) {
      _args[result[1].replace('--','')] = result[3];
    } else {
      _args['_'].push(arg);
    }
  });

  return _args;
}

export const args = parseArgs();

/**
 * Gets value of specified arg
 * @param {string} argName the name of the arg to retrieve
 * @returns {string} value of specified arg
 * @throws will throw error if arg was not specified
 */
export const getArg = (argName) => {
  let arg = args[argName];
  if (!!arg) {
    return arg;
  } else {
    throw(`${argName} was not supplied!`);
  }
}
